
TODO_10_72_28_05: Support `help` for any number of commands.

It also applies to `intercept` and `query_enum`.

The issue is currently fixed via extracting `tree_abs_path_to_interp_id` from FS_33_76_82_84 composite forest.

However, configuring commands like `help` and `intercept` is still cumbersome.
See also TODO_26_08_72_06 interp vs delegator.
